import {Injectable} from '@angular/core';
import {ApplicationBase} from '../../model/application-base';
import {HttpClient, HttpParams} from '@angular/common/http';
import {AppConfigService} from '../../service';
import {BulkResponse} from '../../model/bulk-response';
import {Observable} from 'rxjs';
import {BulkDeployment} from '../../model/bulk-deployment';
import { BulkQueueDetails } from '../../model/bulk-queue-details';

@Injectable({
    providedIn: 'root'
})
export class AppdeploymentService {

    private readonly DEPLOY_APP_KEY = 'APP_DEPLOYMENT'
    private readonly DEPLOY_APP_ID_KEY = 'APP_DEPLOYMENT_ID'

    private selectedApp: string = undefined;
    private selectedAppId: string = undefined;
    private parallelDeploymentsLimit: number = 1;

    public result: BulkResponse[] = [];

    public bulk: BulkDeployment;


    constructor(private http: HttpClient,
                private appConfig: AppConfigService) {
        if (localStorage.getItem(this.DEPLOY_APP_KEY)) {
            this.selectedApp = localStorage.getItem(this.DEPLOY_APP_KEY)
            this.selectedAppId = localStorage.getItem(this.DEPLOY_APP_ID_KEY)
        } else {
            this.selectedApp = '';
            this.selectedAppId = '';
        }
    }

    setSelectedApp(app: ApplicationBase) {
        this.selectedApp = app.name;
        this.selectedAppId = `${app.id}`;
        localStorage.setItem(this.DEPLOY_APP_KEY, this.selectedApp)
        localStorage.setItem(this.DEPLOY_APP_ID_KEY, this.selectedAppId)
    }

    setParallel(parallel: number ) {
        this.parallelDeploymentsLimit = parallel;
    }

    public getSelectedApp() {
        return this.selectedApp;
    }

    public getSelectedAppId() {
        return Number.parseInt(this.selectedAppId, 10);
    }

    protected getUrl(): string {
        return this.appConfig.getApiUrl() + '/bulks/';
    }

    public uploadApplicationFile(file: File, name: string): Observable<BulkDeployment> {
        const formParams = new FormData();
        formParams.append('file', file);
        formParams.append('appName', name)
        formParams.append('limit', this.parallelDeploymentsLimit.toString())
        return this.http.post<BulkDeployment>(this.getUrl() + 'apps', formParams);
    }

    public uploadUserDomainFile(file: File): Observable<BulkDeployment> {
        const formParams = new FormData();
        formParams.append('file', file);
        return this.http.post<BulkDeployment>(this.getUrl() + 'domains', formParams);
    }

    public getBulksDomainDeployments(showDeleted: boolean = false): Observable<BulkDeployment[]> {
        const formParams = new HttpParams().append('deleted', showDeleted);
    
        return this.http.get<BulkDeployment[]>(this.getUrl() + 'domains', {params:formParams});
    }

    public getBulksDomainDeploymentsOwner(): Observable<BulkDeployment[]> {
        return this.http.get<BulkDeployment[]>(this.getUrl() + 'domains/group');
    }

    public getBulksAppDeployments(showDeleted: boolean = false): Observable<BulkDeployment[]> {
        const formParams = new HttpParams().append('deleted', showDeleted);

        return this.http.get<BulkDeployment[]>(this.getUrl() + 'apps', {params:formParams});
    }

    public getBulksAppDeploymentsOwner(): Observable<BulkDeployment[]> {
        return this.http.get<BulkDeployment[]>(this.getUrl() + 'apps/group');
    }

    public getBulkDeployment(id: number): Observable<BulkDeployment> {
        return this.http.get<BulkDeployment>(this.getUrl() + id);
    }

    public getAppBulkDetails(id: number): Observable<Blob> {
        return this.http.get(this.getUrl() + `app/csv/${id}`, {responseType: 'blob'})
    }

    public refreshStatesInBulkDeployment(id: number) : Observable<BulkDeployment> {
        return this.http.get<BulkDeployment>(this.getUrl() + `refresh/${id}`)
    }

    public removeBulkDeployment(id: number, removeAll: boolean)  {
        const params = new HttpParams().set('removeAll', removeAll);
        return this.http.delete(this.getUrl() +`${id}`, { params });
    }

    public getQueueDetails(id: number) : Observable<BulkQueueDetails> {
        return this.http.get<BulkQueueDetails>(this.getUrl() + `queue/${id}`)
    }


}
