import {Injectable} from '@angular/core';
import { ActivatedRouteSnapshot, Router, RouterStateSnapshot } from '@angular/router';
import {AuthService} from './auth.service';
import {ConfigurationService} from '../service';
import { debounceTime } from 'rxjs';

@Injectable()         
export class AuthGuard  {

  constructor(private auth: AuthService, private router: Router, private maintenanceService: ConfigurationService) {}


  public canActivate(route: ActivatedRouteSnapshot, state: RouterStateSnapshot): boolean {
    if (this.auth.isLogged()) {
    
      if(this.auth.hasRole('ROLE_INCOMPLETE') && route.url.toString() !== 'complete') {
          this.router.navigate(['/complete']);
          return false;
      }
      if(this.auth.hasRole("ROLE_NOT_ACCEPTED") && route.url.toString() !== 'terms-acceptance'){
          this.router.navigate(['/terms-acceptance']);
          return false;
      }
      else
          return true;
    }

    // not logged in so redirect to login page
    this.router.navigate(['/welcome/login']);
    return false;
  }

  public canActivateChild(route: ActivatedRouteSnapshot, state: RouterStateSnapshot): boolean {
    return this.canActivate(route, state);
  }
}
